from Products.Five import zcml
from Products.Five import fiveconfigure

from Testing import ZopeTestCase as ztc

from Products.PloneTestCase import PloneTestCase as ptc
from Products.PloneTestCase.layer import onsetup

@onsetup
def setup_idashboard():
    """ The @onsetup decorator causes the execution of this body to be deferred
        until the setup of the Plone site testing layer.
    """
    # Load the ZCML configuration for the slc.dublettefinder package.
    # This includes the other products below as well.
    
    fiveconfigure.debug_mode = True
    import collective.idashboard
    zcml.load_config('configure.zcml', collective.idashboard)
    fiveconfigure.debug_mode = False
    
    # We need to tell the testing framework that these products
    # should be available. This can't happen until after we have loaded
    # the ZCML.
    
    ztc.installPackage('collective.idashboard')
    
setup_idashboard()
ptc.setupPloneSite(products=['collective.idashboard'])

class iDashboardTestCase(ptc.PloneTestCase):
    """Base class used for test cases
    """
        
class iDashboardFunctionalTestCase(ptc.FunctionalTestCase):
    """Test case class used for functional (doc-)tests
    """





# Licensed under GNU General Public License (GPL)
# http://www.opensource.org/licenses/gpl-license.php

import logging

from Products.Archetypes import listTypes
from Products.Archetypes.atapi import *
from Products.CMFCore import utils as cmfutils

from config import *

log = logging.getLogger('collective.idashboard')
log.debug('Installing Product')

def initialize(context):
    """initialize product (called by zope)"""
    import browser

    content_types, constructors, ftis = process_types(
        listTypes(PROJECTNAME),
        PROJECTNAME)

    cmfutils.ContentInit(
        PROJECTNAME + ' Content',
        content_types      = content_types,
        permission         = DEFAULT_ADD_CONTENT_PERMISSION,
        extra_constructors = constructors,
        fti                = ftis,
        ).initialize(context)




from zope.component import getUtility, getMultiAdapter
from zope.app.component.hooks import setHooks, setSite
from zope.component.interfaces import IFactory
from zope.event import notify

from zExceptions import Unauthorized

from plone.portlets.interfaces import IPortletManager
from plone.portlets.interfaces import IPortletRetriever
from plone.portlets.interfaces import IPortletType
from plone.portlets.constants import USER_CATEGORY
from plone.portlets.utils import hashPortletInfo

from plone.app.portlets.utils import assignment_mapping_from_key
from plone.app.portlets.tests.base import PortletsTestCase

from Products.CMFCore.utils import getToolByName
from Products.PluggableAuthService.events import PrincipalCreated
from Products.PluggableAuthService.PropertiedUser import PropertiedUser

class TestiDashboard(PortletsTestCase):

    def afterSetUp(self):
        setHooks()
        setSite(self.portal)

    def test_drag_and_drop(self):
        pm = getToolByName(self.portal, 'portal_membership')
        key = pm.getAuthenticatedMember().id

        movePortlet = self.portal.restrictedTraverse('@@movePortlet')
        for i in range(1,3):
            manager = u'plone.dashboard%d' % i

            mapping = assignment_mapping_from_key(self.portal,
                manager_name=manager, category=USER_CATEGORY, key=key)

            portlet = mapping['news']
            portlet_hash = hashPortletInfo(dict(manager=manager,
                                                category=USER_CATEGORY,
                                                key=key, 
                                                name=portlet.__name__))
        
            new_manager = u'plone.dashboard%d' % (i+1)
            portlet_hash = movePortlet(portlet_hash, new_manager, '')

            new_mapping = assignment_mapping_from_key(self.portal,
                manager_name=new_manager, category=USER_CATEGORY, key=key)

            self.failUnless('news' in new_mapping)

        portlet_hash = movePortlet(portlet_hash, 'plone.dashboard1', '')
        mapping = assignment_mapping_from_key(self.portal,
            manager_name='plone.dashboard1', category=USER_CATEGORY, key=key)
        self.failUnless('news' in mapping)

    def test_portlet_delete(self):
        manager = 'plone.dashboard1'
        pm = getToolByName(self.portal, 'portal_membership')
        key = pm.getAuthenticatedMember().id
        mapping = assignment_mapping_from_key(self.portal,
            manager_name=manager, category=USER_CATEGORY, key=key)
        portlet = mapping['news']
        portlet_hash = hashPortletInfo(dict(manager=manager,
                                            category=USER_CATEGORY,
                                            key=key, 
                                            name=portlet.__name__))

        removePortlet = self.portal.restrictedTraverse('@@removePortlet')
        removePortlet(portlet_hash)
        mapping = assignment_mapping_from_key(self.portal,
            manager_name=manager, category=USER_CATEGORY, key=key)

        self.failIf('news' in mapping)

def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestiDashboard))
    return suite




from setuptools import setup, find_packages
import os

version = '1.1'

setup(name='collective.idashboard',
      version=version,
      description="This Plone add-on product gives your dashboard features similiar to those of the iGoogle dashboard.",
      long_description=open("README.txt").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='plone dashboard idashboard igoogle',
      author='JC Brand',
      author_email='jc@opkode.com',
      url='http://plone.org/products/collective.idashboard',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['collective'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
          'collective.js.jquery',
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )



# Licensed under GNU General Public License (GPL)
# http://www.opensource.org/licenses/gpl-license.php

from Products.CMFCore.permissions import setDefaultRoles

PROJECTNAME = "collective.idashboard"

DEFAULT_ADD_CONTENT_PERMISSION = "Add portal content"
setDefaultRoles(DEFAULT_ADD_CONTENT_PERMISSION, ('Manager', 'Owner'))

product_globals = globals()

